staggered property
Whether alternate rows are offset by half columnSpacing to create a brick pattern, making cropping more difficult.
Defaults to true.
Implementation
final bool staggered;
Whether alternate rows are offset by half columnSpacing to create a brick pattern, making cropping more difficult.
Defaults to true.
final bool staggered;