ForensicConfig class

Immutable configuration for forensic (invisible) watermarking.

Controls the spread-spectrum LSB embedding parameters.

Constructors

ForensicConfig({int redundancy = 5, int bitsPerChannel = 1})
Creates a forensic watermark configuration.
const

Properties

bitsPerChannel int
Number of least-significant bits used per channel.
final
hashCode int
The hash code for this object.
no setteroverride
redundancy int
Number of times the payload is repeated for error correction.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? redundancy, int? bitsPerChannel}) ForensicConfig
Creates a copy of this config with the given fields replaced.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override