Watermark constructor
const
Watermark({
- Key? key,
- required String text,
- WatermarkStyle style = const WatermarkStyle(),
- bool enabled = true,
- required Widget child,
Creates a watermark overlay over child.
The text is tiled across the child area according to style.
Set enabled to false to hide the watermark without removing the
widget from the tree.
Implementation
const Watermark({
super.key,
required this.text,
this.style = const WatermarkStyle(),
this.enabled = true,
required this.child,
});